<?php

namespace NCSU\Auth\Adapter;

use NCSU\Auth\Adapter\WrapAuthAdapter;
use NCSU\Auth\Http\Request;

/**
 * @runTestsInSeparateProcesses
 */
class ChainedAuthAdapterTest extends \PHPUnit_Framework_TestCase
{

    /** @test */
    public function it_should_return_correct_identity_when_only_shib_is_enabled()
    {
        $this->beShibbolethUser('cacard');

        $adapter = new ChainedAuthAdapter();
        $result = $adapter->authenticate();

        $this->assertEquals('cacard', $result->getIdentity());
    }

    /** @test */
    public function it_should_return_correct_identity_when_only_wrap_is_enabled()
    {
        $this->beWrapUser('cacard');

        $adapter = new ChainedAuthAdapter();
        $result = $adapter->authenticate();

        $this->assertEquals('cacard', $result->getIdentity());
    }

    /** @test */
    public function it_should_prioritize_shibboleth_over_wrap()
    {
        // Using post-fixes to prove which is used. In production, these would be equivalent
        // assuming proper configuration.
        $this->beShibbolethUser('cacard-shib');
        $this->beWrapUser('cacard-wrap');

        $adapter = new ChainedAuthAdapter();
        $result = $adapter->authenticate();

        $this->assertEquals('cacard-shib', $result->getIdentity());
    }

    private function beWrapUser($userId)
    {
        $_SERVER['WRAP_USERID'] = $userId;
    }

    private function beShibbolethUser($userId)
    {
        $_SERVER['Shib-Session-ID'] = 'foo';
        $_SERVER['SHIB_UID'] = $userId;
    }
}
